@@ -547,6 +547,26 @@ quitting_cb(void *data)
 	purple_debug_misc("signals test", "quitting ()\n");
 }
 
+static void
+printhash(gpointer key, gpointer value, gpointer data)
+{
+	char *a = (char *)key;
+	char *b = (char *)value;
+	GString *str = (GString *)data;
+	g_string_append_printf(str, "   [%s] = [%s]\n", a, b ? b : "(null)");
+}
+
+static gboolean
+uri_handler(const char *proto, const char *cmd, GHashTable *params)
+{
+	GString *str = g_string_new("\n{\n");
+	g_hash_table_foreach(params, printhash, str);
+	g_string_append_c(str, '}');
+	purple_debug_misc("signals test", "uri handler (%s, %s, %s)\n", proto, cmd, str->str);
+	g_string_free(str, TRUE);
+	return FALSE;
+}
+
 /**************************************************************************
  * File transfer signal callbacks
  **************************************************************************/
@@ -572,12 +592,12 @@ ft_send_start_cb(PurpleXfer *xfer, gpointer data) {
 
 static void
 ft_recv_cancel_cb(PurpleXfer *xfer, gpointer data) {
-	purple_debug_misc("signals test", "file receive canceled\n");
+	purple_debug_misc("signals test", "file receive cancelled\n");
 }
 
 static void
 ft_send_cancel_cb(PurpleXfer *xfer, gpointer data) {
-	purple_debug_misc("signals test", "file send canceled\n");
+	purple_debug_misc("signals test", "file send cancelled\n");
 }
 
 static void
@@ -615,11 +635,11 @@ notify_email_cb(char *subject, char *from, char *to, char *url) {
 
 static void
 notify_emails_cb(char **subjects, char **froms, char **tos, char **urls, guint count) {
-	int i;
-	purple_debug_misc("signals test", "notify emails: count=%d\n", count);
+	guint i;
+	purple_debug_misc("signals test", "notify emails: count=%u\n", count);
 	for(i=0; i<count && i<5; i++) {
 		if(subjects[i]==NULL || froms[i]==NULL || tos[i]==NULL || urls[i]==NULL) continue;
-		purple_debug_misc("signals test", "notify emails[%d]: subject=%s, from=%s, to=%s, url=%s\n",
+		purple_debug_misc("signals test", "notify emails[%u]: subject=%s, from=%s, to=%s, url=%s\n",
 			i, subjects[i], froms[i], tos[i], urls[i]);
 	}
 }
@@ -671,7 +691,7 @@ jabber_watched_iq(PurpleConnection *pc, const char *type, const char *id,
 	                  type, id, from, child, child->name,
 	                  xmlnode_get_namespace(child));
 
-	if (g_str_equal(type, "get") || g_str_equal(type, "set")) {
+	if (purple_strequal(type, "get") || purple_strequal(type, "set")) {
 		/* Send the requisite reply */
 		xmlnode *iq = xmlnode_new("iq");
 		xmlnode_set_attrib(iq, "to", from);
@@ -820,6 +840,8 @@ plugin_load(PurplePlugin *plugin)
 	/* Core signals */
 	purple_signal_connect(core_handle, "quitting",
 						plugin, PURPLE_CALLBACK(quitting_cb), NULL);
+	purple_signal_connect(core_handle, "uri-handler",
+						plugin,	PURPLE_CALLBACK(uri_handler), NULL);
 
 	/* File transfer signals */
 	purple_signal_connect(ft_handle, "file-recv-accept",
