@@ -68,7 +68,6 @@ struct _PurpleBOSHConnection {
 	char *path;
 	guint16 port;
 
-	gboolean pipelining;
 	gboolean ssl;
 
 	enum {
@@ -212,7 +211,6 @@ jabber_bosh_connection_init(JabberStream *js, const char *url)
 	conn->port = port;
 	conn->path = g_strdup_printf("/%s", path);
 	g_free(path);
-	conn->pipelining = TRUE;
 
 	if (purple_ip_address_is_valid(host))
 		js->serverFQDN = g_strdup(js->user->domain);
@@ -285,12 +283,6 @@ find_available_http_connection(PurpleBOSHConnection *conn)
 	if (purple_debug_is_verbose())
 		debug_dump_http_connections(conn);
 
-	/* Easy solution: Does everyone involved support pipelining? Hooray! Just use
-	 * one TCP connection! */
-	if (conn->pipelining)
-		return conn->connections[0]->state == HTTP_CONN_CONNECTED ?
-				conn->connections[0] : NULL;
-
 	/* First loop, look for a connection that's ready */
 	for (i = 0; i < NUM_HTTP_CONNECTIONS; ++i) {
 		if (conn->connections[i] &&
@@ -432,7 +424,7 @@ static gboolean jabber_bosh_connection_error_check(PurpleBOSHConnection *conn, x
 
 	type = xmlnode_get_attrib(node, "type");
 
-	if (type != NULL && !strcmp(type, "terminate")) {
+	if (purple_strequal(type, "terminate")) {
 		conn->state = BOSH_CONN_OFFLINE;
 		purple_connection_error_reason(conn->js->gc,
 			PURPLE_CONNECTION_ERROR_OTHER_ERROR,
@@ -465,27 +457,6 @@ jabber_bosh_connection_send_keepalive(PurpleBOSHConnection *bosh)
 	send_timer_cb(bosh);
 }
 
-static void
-jabber_bosh_disable_pipelining(PurpleBOSHConnection *bosh)
-{
-	/* Do nothing if it's already disabled */
-	if (!bosh->pipelining)
-		return;
-
-	purple_debug_info("jabber", "BOSH: Disabling pipelining on conn %p\n",
-	                            bosh);
-	bosh->pipelining = FALSE;
-	if (bosh->connections[1] == NULL) {
-		bosh->connections[1] = jabber_bosh_http_connection_init(bosh);
-		http_connection_connect(bosh->connections[1]);
-	} else {
-		/* Shouldn't happen; this should be the only place pipelining
-		 * is turned off.
-		 */
-		g_warn_if_reached();
-	}
-}
-
 static void jabber_bosh_connection_received(PurpleBOSHConnection *conn, xmlnode *node) {
 	xmlnode *child;
 	JabberStream *js = conn->js;
@@ -505,10 +476,10 @@ static void jabber_bosh_connection_received(PurpleBOSHConnection *conn, xmlnode
 			 * the right xmlns on these packets.  See #11315.
 			 */
 			if ((xmlns == NULL /* shouldn't happen, but is equally wrong */ ||
-					g_str_equal(xmlns, NS_BOSH)) &&
-				(g_str_equal(child->name, "iq") ||
-				 g_str_equal(child->name, "message") ||
-				 g_str_equal(child->name, "presence"))) {
+					purple_strequal(xmlns, NS_BOSH)) &&
+				(purple_strequal(child->name, "iq") ||
+				 purple_strequal(child->name, "message") ||
+				 purple_strequal(child->name, "presence"))) {
 				xmlnode_set_namespace(child, NS_XMPP_CLIENT);
 			}
 			jabber_process_packet(js, &child);
@@ -726,11 +697,6 @@ static void http_connection_disconnected(PurpleHTTPConnection *conn)
 		conn->requests = 0;
 	}
 
-	if (conn->bosh->pipelining) {
-		/* Hmmmm, fall back to multiple connections */
-		jabber_bosh_disable_pipelining(conn->bosh);
-	}
-
 	if (!had_requests)
 		/* If the server disconnected us without any requests, let's
 		 * just wait until we have something to send before we reconnect
@@ -807,7 +773,6 @@ jabber_bosh_http_connection_process(PurpleHTTPConnection *conn)
 
 			if (!g_ascii_strncasecmp(tmp, "close", strlen("close"))) {
 				conn->close = TRUE;
-				jabber_bosh_disable_pipelining(conn->bosh);
 			}
 		}
 
